#include "AliAnalysisTaskPt.h"

//
// This class is ment as an example of how to get access to the MC
// data and ESD data with AliAnalysisTaks class.
//
// It is based on existing classes in AliRoot.
//
#include <TMath.h>

#include <AliAnalysisManager.h>
#include <AliESD.h>
#include <AliESDtrack.h>
#include <AliMCEventHandler.h>
#include <AliMCEvent.h>
#include <AliStack.h>

ClassImp(AliAnalysisTaskPt)

//________________________________________________________________________
AliAnalysisTaskPt::AliAnalysisTaskPt() : 
  AliAnalysisTask(), 
  fChain(0), 
  fESD(0), 
  fListOfHists(0), 
  fHistPt(0),
  fHistPtMC(0) 
{
  //
  // Default constructor (should not be used)
  //
  fDebug = 0;
}

//________________________________________________________________________
AliAnalysisTaskPt::AliAnalysisTaskPt(const char *name) : 
  AliAnalysisTask(name, "AliAnalysisTaksPt"), 
  fChain(0), 
  fESD(0), 
  fListOfHists(0),
  fHistPt(0),
  fHistPtMC(0) 
{
  //
  // Normal constructor
  //
  
  // Input slot #0 works with a TChain
  DefineInput(0, TChain::Class());
  // Output slot #0 writes into a TList
  DefineOutput(0, TList::Class());

  fDebug = 0;
}

//________________________________________________________________________
void AliAnalysisTaskPt::ConnectInputData(Option_t *) 
{
  //
  // Connect the input data
  //
  printf("   ConnectInputData %s\n", GetName());
  fChain = (TChain*)GetInputData(0);
  fESD = new AliESDEvent();
  fESD->ReadFromTree(fChain);
}

//________________________________________________________________________
void AliAnalysisTaskPt::CreateOutputObjects() 
{
  //
  // Connect the output objects
  //
  OpenFile(1);
  fListOfHists = new TList();
  
  fHistPtMC = new TH1F("fHistPtMC","Pt dist (MC); P_{T} [GeV]; #frac{dN}{dP_{T}}",
		       15, 0.1, 3.1);
  fHistPtMC->Sumw2();
  fHistPt = new TH1F("fHistPt","Pt dist; P_{T} [GeV]; #frac{dN}{dP_{T}}",
		     15, 0.1, 3.1);
  fHistPt->Sumw2();
  fListOfHists->Add(fHistPtMC);
  fListOfHists->Add(fHistPt);
}

//________________________________________________________________________
void AliAnalysisTaskPt::Exec(Option_t *) {
  //
  // Execute analysis for current event
  //

  // Get MC input data
  AliMCEventHandler* mctruth = (AliMCEventHandler*) 
    ((AliAnalysisManager::GetAnalysisManager())->GetMCtruthEventHandler());
  if (mctruth) {
    AliMCEvent* mc = mctruth->MCEvent();
    Int_t ntrack = mc->GetNumberOfTracks();
    for (Int_t i = 0; i < ntrack; i++) {

      AliVParticle* particle = mc->GetTrack(i);
      if(TMath::Abs(particle->Eta()) < 0.5)
	fHistPtMC->Fill(particle->Pt());	
    }	

    // or alternatively
    //    AliStack* mcStack = mctruth->MCEvent()->Stack();
    //    printf("AliAnalysisTaskPt: Number of tracks on stack %5d\n", 
    //	   mcStack->GetNtrack());
  }
  
  // Get MC input data
  AliESD* old = fESD->GetAliESDOld();
  if (old) {
    fESD->CopyFromOldESD();
    old->Reset();
  }
    
  Long64_t ientry = fChain->GetReadEntry();
  printf("Analysing event # %5d\n", (Int_t) ientry);

  for(Int_t iTracks = 0; iTracks < fESD->GetNumberOfTracks(); iTracks++) {

    AliESDtrack * track = fESD->GetTrack(iTracks);
    //UInt_t status = track->GetStatus();
    //     Double_t momentum[3];
    //     track->GetPxPyPz(momentum);
    
    //     Double_t pt    = TMath::Sqrt(TMath:Pow(momentum[0],2) + 
    // 				 TMath::Pow(momentum[1],2));
    if(TMath::Abs(track->Eta()) < 0.5)
      fHistPt->Fill(track->Pt());
  }//track loop 

  // Post final data. It will be written to a file with option "RECREATE"
  PostData(0, fListOfHists);
}      

//________________________________________________________________________
void AliAnalysisTaskPt::Terminate(Option_t *) {
  //
  // Terminate loop
  //
  printf("AliAnalysisTaskPt: Terminate() \n");
}
